@@ -70,17 +70,18 @@
 #'     geom_sf()
 #' }
 #' }
-reverse_geo_lite_sf <- function(lat,
-                                long,
-                                address = "address",
-                                full_results = FALSE,
-                                return_coords = TRUE,
-                                verbose = FALSE,
-                                nominatim_server =
-                                  "https://nominatim.openstreetmap.org/",
-                                progressbar = TRUE,
-                                custom_query = list(),
-                                points_only = TRUE) {
+reverse_geo_lite_sf <- function(
+  lat,
+  long,
+  address = "address",
+  full_results = FALSE,
+  return_coords = TRUE,
+  verbose = FALSE,
+  nominatim_server = "https://nominatim.openstreetmap.org/",
+  progressbar = TRUE,
+  custom_query = list(),
+  points_only = TRUE
+) {
   # Check inputs
   if (!is.numeric(lat) || !is.numeric(long)) {
     stop("lat and long must be numeric")
@@ -104,12 +105,13 @@ reverse_geo_lite_sf <- function(lat,
     message("longitudes have been restricted to [-180, 180]")
   }
 
-
   # Dedupe for query using data frame
 
   init_key <- dplyr::tibble(
-    lat_key_int = lat, long_key_int = long,
-    lat_cap_int = lat_cap, long_cap_int = long_cap
+    lat_key_int = lat,
+    long_key_int = long,
+    lat_cap_int = lat_cap,
+    long_cap_int = long_cap
   )
   key <- dplyr::distinct(init_key)
 
@@ -123,7 +125,6 @@ reverse_geo_lite_sf <- function(lat,
 
   seql <- seq(1, ntot, 1)
 
-
   all_res <- lapply(seql, function(x) {
     if (progressbar) {
       setTxtProgressBar(pb, x)
@@ -146,8 +147,9 @@ reverse_geo_lite_sf <- function(lat,
 
     res_single
   })
-  if (progressbar) close(pb)
-
+  if (progressbar) {
+    close(pb)
+  }
 
   all_res <- dplyr::bind_rows(all_res)
 
@@ -156,10 +158,14 @@ reverse_geo_lite_sf <- function(lat,
     # Join with indexes
     tmplt <- sf::st_drop_geometry(all_res)[, c("lat_key_int", "long_key_int")]
     tmplt$rindex <- seq_len(nrow(tmplt))
-    getrows <- dplyr::left_join(init_key, tmplt, by = c(
-      "lat_key_int",
-      "long_key_int"
-    ))
+    getrows <- dplyr::left_join(
+      init_key,
+      tmplt,
+      by = c(
+        "lat_key_int",
+        "long_key_int"
+      )
+    )
 
     # Select rows
     all_res <- all_res[as.double(getrows$rindex), ]
@@ -178,16 +184,17 @@ reverse_geo_lite_sf <- function(lat,
 
 #' @noRd
 #' @inheritParams reverse_geo_lite_sf
-reverse_geo_lite_sf_single <- function(lat_cap,
-                                       long_cap,
-                                       address = "address",
-                                       full_results = TRUE,
-                                       return_coords = TRUE,
-                                       verbose = TRUE,
-                                       nominatim_server =
-                                         "https://nominatim.openstreetmap.org/",
-                                       custom_query = list(),
-                                       points_only = FALSE) {
+reverse_geo_lite_sf_single <- function(
+  lat_cap,
+  long_cap,
+  address = "address",
+  full_results = TRUE,
+  return_coords = TRUE,
+  verbose = TRUE,
+  nominatim_server = "https://nominatim.openstreetmap.org/",
+  custom_query = list(),
+  points_only = FALSE
+) {
   # First build the api address. If the passed nominatim_server does not end
   # with a trailing forward-slash, add one
   api <- prepare_api_url(nominatim_server, "reverse?")
@@ -195,7 +202,9 @@ reverse_geo_lite_sf_single <- function(lat_cap,
   # Compose url
   url <- paste0(api, "lat=", lat_cap, "&lon=", long_cap, "&format=geojson")
 
-  if (!isTRUE(points_only)) url <- paste0(url, "&polygon_geojson=1")
+  if (!isTRUE(points_only)) {
+    url <- paste0(url, "&polygon_geojson=1")
+  }
   if (isFALSE(full_results)) {
     url <- paste0(url, "&addressdetails=0")
   } else {
@@ -205,7 +214,6 @@ reverse_geo_lite_sf_single <- function(lat_cap,
   # Add options
   url <- add_custom_query(custom_query, url)
 
-
   # Download to temp file
   json <- tempfile(fileext = ".geojson")
   res <- api_call(url, json, isFALSE(verbose))
@@ -219,13 +227,14 @@ reverse_geo_lite_sf_single <- function(lat_cap,
     return(invisible(out))
   }
 
-
   # Empty query
   result_init <- jsonlite::fromJSON(json, flatten = TRUE)
   if ("error" %in% names(result_init)) {
     message(
       "No results for query lon=",
-      long_cap, ", lat=", lat_cap
+      long_cap,
+      ", lat=",
+      lat_cap
     )
     out <- empty_sf(empty_tbl_rev(tbl_query, address))
     return(invisible(out))
@@ -240,7 +249,6 @@ reverse_geo_lite_sf_single <- function(lat_cap,
   # Add lat lon
   sf_clean <- dplyr::bind_cols(sfobj, tbl_query)
 
-
   # Keep names
   result_out <- keep_names_rev(sf_clean, address, return_coords, full_results)
 
